@@ -66,7 +66,9 @@ void fEBLinearEpisEff(double *BASIS, double *y, double *a_gamma, double *b_gamma
 	// set a limit for number of basis
 	if(verbose >1) Rprintf("start EBLasso-NEG with a: %f, \tb: %f\n",a_gamma[0], b_gamma[0]);
 //------------------------------------------------------------	
-	int basisMax			= *bMax;
+	int basisMax_io			= *bMax;
+	int basisMax 			=*bMax;
+	if(K>=100) basisMax = 10*K;
 //------------------------------------------------------------	
 	//if (basisMax>M_full)	basisMax = M_full;
 	if(verbose >1) Rprintf("M_full: %d; basisMax: %d\n",M_full,basisMax);
@@ -100,10 +102,10 @@ void fEBLinearEpisEff(double *BASIS, double *y, double *a_gamma, double *b_gamma
 		//Scales[i]			=sqrt(temp);
 		Scales[i]			=(float)sqrt(temp);
 	}
-	readPtr1 				= &Beta[basisMax*2];
-	F77_CALL(dcopy)(&basisMax,&zero_blas,&inc0,readPtr1,&inci);  //dcopy(n, x, incx, y, incy) ---> y = x
-	readPtr1 				= &Beta[basisMax*3];
-	F77_CALL(dcopy)(&basisMax,&zero_blas,&inc0,readPtr1,&inci);  //dcopy(n, x, incx, y, incy) ---> y = x
+	readPtr1 				= &Beta[basisMax_io*2];
+	F77_CALL(dcopy)(&basisMax_io,&zero_blas,&inc0,readPtr1,&inci);  //dcopy(n, x, incx, y, incy) ---> y = x
+	readPtr1 				= &Beta[basisMax_io*3];
+	F77_CALL(dcopy)(&basisMax_io,&zero_blas,&inc0,readPtr1,&inci);  //dcopy(n, x, incx, y, incy) ---> y = x
 		
 	
 	//PartII kk
@@ -216,9 +218,9 @@ void fEBLinearEpisEff(double *BASIS, double *y, double *a_gamma, double *b_gamma
 	int Meffect = M;
 	
 	//in Binary Model: M is actually length(effect) + 1;
-	if(M>basisMax)
+	if(M>basisMax_io)
 	{
-		Meffect = basisMax;
+		Meffect = basisMax_io;
 	}
 		for(i=0;i<Meffect;i++)
 		{
@@ -229,7 +231,7 @@ void fEBLinearEpisEff(double *BASIS, double *y, double *a_gamma, double *b_gamma
 			if(index<K)
 			{
 				Beta[kk] = index + 1;
-				Beta[basisMax+kk] = index + 1;		
+				Beta[basisMax_io+kk] = index + 1;		
 			}else //compute i,j
 			{
 				l = index;
@@ -251,12 +253,12 @@ void fEBLinearEpisEff(double *BASIS, double *y, double *a_gamma, double *b_gamma
 					}
 				}
 				Beta[kk] = locus1 +1;
-				Beta[basisMax+kk] = locus2  +1;	
+				Beta[basisMax_io+kk] = locus2  +1;	
 			
 			}		
 			scal = (double)Scales[index];
-			Beta[basisMax*2 + kk]	= Mu[i]/scal;
-			Beta[basisMax*3 + kk]  = SIGMA[i*M + i]/(scal*scal);
+			Beta[basisMax_io*2 + kk]	= Mu[i]/scal;
+			Beta[basisMax_io*3 + kk]  = SIGMA[i*M + i]/(scal*scal);
 			kk = kk + 1;
 		}
 //
@@ -566,7 +568,7 @@ if(verbose >3) Rprintf("check point 3: before loop \n");
 			//Rprintf("\t\t newAlpha: %f\n",newAlpha);
             // B_phi*PHI2*SIGMA2        tmp = B_phi*PHI2 
             index					= M + 1;
-			if(index > (basisMax -10)) {
+			if(index > (basisMax -10) && (N*K)>1e7 ) {
 				Rprintf("bases: %d, warning: out of Memory, alloc more to Neffect!\n",index);
 			}//return;
 
